@@ -28,16 +28,12 @@ class RescaleImage(object):
             Note: You do not need to resize the bounding boxes. ONLY RESIZE THE IMAGE.
         '''
         image_resized = np.array([])
-        
         if(isinstance(self.output_size, tuple)):
             image_resized = resize(image, self.output_size)
-            return image_resized
-        
         elif(isinstance(self.output_size, int)):
             h, w, _ = image.shape
             if(w < h):
-                image_resized = resize(image, (math.floor(h*self.output_size/w), self.output_size), anti_aliasing = True)
-                return image_resized
+                image_resized = resize(image, (math.floor(h*self.output_size/w), self.output_size))
             else:
-                image_resized = resize(image, (self.output_size, math.floor(w*self.output_size/h)), anti_aliasing = True)
-                return image_resized
+                image_resized = resize(image, (self.output_size, math.floor(w*self.output_size/h)))    
+        return image_resized
